{ config, pkgs, ... }: let
  tex = pkgs.texlive.combine {
    inherit (pkgs.texlive) scheme-medium
      latexmk
      amsmath;
  };
in
{
  imports = [ ./homebrew.nix ./yabai-skhd.nix ];
  # List packages installed in system profile. To search by name, run:
  # $ nix-env -qaP | grep wget
  environment = {
    variables = {
      EDITOR = "vim";
      VISUAL = "vim";
    };
    systemPackages = with pkgs; [
      vim
      ripgrep
      fd
      gnupg

      direnv
      nix-direnv
      rustup
      elan
      poetry
      tex
      cmake

      ispell

      # Media
      imagemagick
      fontconfig
    ];
  };

  # Auto upgrade nix package and the daemon service.
  services = {
    nix-daemon.enable = true;
    karabiner-elements.enable = true;
    sketchybar = {
      enable = true;
    };
  };
  nix = {
    package = pkgs.nix;
    settings.experimental-features = "nix-command flakes";
  };

  # Enable alternative shell support in nix-darwin.
  programs.fish.enable = true;

  # Used for backwards compatibility, please read the changelog before changing.
  # $ darwin-rebuild changelog
  system = {
    stateVersion = 5;
    defaults = {
      dock = {
        autohide = true;
        orientation = "bottom";
      };
    };
  };
}
